[−][src]Struct suffix_array::SuffixArray
Suffix array for searching byte strings.
Methods
impl<'s> SuffixArray<'s>[src]
pub fn new(s: &'s [u8]) -> Self[src]
pub fn set(&mut self, s: &'s [u8])[src]
pub fn fit(&mut self)[src]
pub fn len(&self) -> usize[src]
Length of the underlying byte string.
pub fn is_empty(&self) -> bool[src]
Test if the underlying byte string is empty.
pub fn contains(&self, sub: &[u8]) -> bool[src]
Test if contains given sub-string.
pub fn search_all(&self, sub: &[u8]) -> &[u32][src]
Search for all the unsorted overlapping occurrence of given sub-string.
pub fn search_prefix(&self, pat: &[u8]) -> Range<usize>[src]
Search for one longest infix in the byte string that matches a prefix of the given pattern.